==> cloud-4.3.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/SelectBlock.tsx <==
import { Form } from 'react-bootstrap';

const SelectBlock = ({
  label, value, setValue, recordList, required
}: {
  label: string,
  value: string,
  setValue: (s: string) => void,
  recordList: { value: string, label: string, group?: string }[],
  required: boolean
}) => {
  // If the contents of the select box are not yet available.
  if (recordList.length === 0) {
    return <Form.Group className="form-item js-form-item">
      <Form.Label className={'control-label' + (required ? ' form-required' : '')}>{label}</Form.Label>
      <div className="select-wrapper">
        <Form.Select className="form-control">
          <option value="">{'- Select -'}</option>
        </Form.Select>
      </div>
    </Form.Group>;
  }

  // If the select box is not grouped.
  if (typeof recordList[0].group === 'undefined') {
    return <Form.Group className="form-item js-form-item">
      <Form.Label className={'control-label' + (required ? ' form-required' : '')}>{label}</Form.Label>
      <div className="select-wrapper">
        <Form.Select className="form-control" value={value} onChange={(e) => {
          setValue(e.currentTarget.value);
        }}>
          <option value="">{'- Select -'}</option>
          {
            recordList.map((d) => {
              return <option key={d.value} value={d.value}>{d.label}</option>;
            })
          }
        </Form.Select>
      </div>
    </Form.Group>;
  }

  // If the select box is grouped.
  const groups: string[] = [];
  for (const record of recordList) {
    const group = record.group!!;
    if (!groups.includes(group)) {
      groups.push(group);
    }
  }

  return <Form.Group className="form-item js-form-item">
    <Form.Label className={'control-label' + (required ? ' form-required' : '')}>{label}</Form.Label>
    <div className="select-wrapper">
      <Form.Select className="form-control" value={value} onChange={(e) => {
        setValue(e.currentTarget.value);
      }}>
        <option value="">{'- Select -'}</option>
        {
          groups.map((group) => {
            return <optgroup key={group} label={group}>
              {
                recordList
                  .filter((r) => r.group === group)
                  .map((d) => {
                    return <option key={d.value} value={d.value}>{d.label}</option>;
                  })
              }
            </optgroup>;
          })
        }
      </Form.Select>
    </div>
  </Form.Group>;
}

export default SelectBlock;

==> cloud-5.0.0-rc1.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/SelectBlock.tsx <==
import { Form } from 'react-bootstrap';

const SelectBlock = ({
  label, value, defaultValue, setValue, recordList, required
}: {
  label: string,
  value: string,
  defaultValue: string,
  setValue: (s: string) => void,
  recordList: { value: string, label: string, group?: string }[],
  required: boolean
}) => {
  // If the contents of the select box are not yet available.
  if (recordList.length === 0) {
    return <Form.Group className="form-item js-form-item">
      <Form.Label className={'control-label' + (required ? ' form-required' : '')}>{label}</Form.Label>
      <div className="select-wrapper">
        <Form.Select className="form-control">
          <option value="">{'- Select -'}</option>
        </Form.Select>
      </div>
    </Form.Group>;
  }

  // If the select box is not grouped.
  if (typeof recordList[0].group === 'undefined') {
    return <Form.Group className="form-item js-form-item">
      <Form.Label className={'control-label' + (required ? ' form-required' : '')}>{label}</Form.Label>
      <div className="select-wrapper">
        <Form.Select className="form-control" value={value || defaultValue} onChange={(e) => {
          setValue(e.currentTarget.value);
        }}>
          <option value="">{'- Select -'}</option>
          {
            recordList.map((d) => {
              return <option key={d.value} value={d.value}>{d.label}</option>;
            })
          }
        </Form.Select>
      </div>
    </Form.Group>;
  }

  // If the select box is grouped.
  const groups: string[] = [];
  for (const record of recordList) {
    const group = record.group!!;
    if (!groups.includes(group)) {
      groups.push(group);
    }
  }

  return <Form.Group className="form-item js-form-item">
    <Form.Label className={'control-label' + (required ? ' form-required' : '')}>{label}</Form.Label>
    <div className="select-wrapper">
      <Form.Select className="form-control" value={value || defaultValue} onChange={(e) => {
        setValue(e.currentTarget.value);
      }}>
        <option value="">{'- Select -'}</option>
        {
          groups.map((group) => {
            return <optgroup key={group} label={group}>
              {
                recordList
                  .filter((r) => r.group === group)
                  .map((d) => {
                    return <option key={d.value} value={d.value}>{d.label}</option>;
                  })
              }
            </optgroup>;
          })
        }
      </Form.Select>
    </div>
  </Form.Group>;
}

export default SelectBlock;
